Crate tattoy_protocol

Crate tattoy_protocol 

These are all the types that a plugin needs to function.

Structs

Cell
A cell represents a single character in the terminal.
CellBuilder
Use builder syntax to set the inputs and finish with build().
Pixel
Output from the plugin that renders pixels in the terminal.
PixelBuilder
Use builder syntax to set the inputs and finish with build().

Enums

PluginInputMessages
The various kinds of messages that Tattoy can send to the plugin.
PluginOutputMessages
All the message kinds that the plugin can send to Tattoy.

Type Aliases

Colour
An RGBA colour.