PluginInputMessages

Enum PluginInputMessages 

#[non_exhaustive]
pub enum PluginInputMessages { PTYUpdate { size: (u16, u16), cells: Vec<Cell>, cursor: (u16, u16), }, TTYResize { width: u16, height: u16, }, }
The various kinds of messages that Tattoy can send to the plugin.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PTYUpdate

The current contents of the PTY screen. It does not contain any of the scrollback.

Fields

size: (u16, u16)

The size of terminal in colums and rows.

cells: Vec<Cell>

All the cell data for the current terminal. Blank cells are not included.

cursor: (u16, u16)

The current position of the cursor.



TTYResize

Sent whenever the terminal resizes.

Fields

width: u16

The number of columns in the new terminal size.

height: u16

The number of rows in the new terminal size.