#[non_exhaustive]pub enum PluginOutputMessages {
OutputText {
text: String,
coordinates: (u32, u32),
bg: Option<Colour>,
fg: Option<Colour>,
},
OutputCells(Vec<Cell>),
OutputPixels(Vec<Pixel>),
}Expand description
All the message kinds that the plugin can send to Tattoy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OutputText
Output from the plugin that renders text of arbitrary length in the terminal.
Fields
OutputCells(Vec<Cell>)
Output an arbitrary amount of cells to the terminal. It does not need to include blank cells.
OutputPixels(Vec<Pixel>)
Output from the plugin that renders pixels in the terminal.