PixelBuilder

Struct PixelBuilder 

pub struct PixelBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> PixelBuilder<S>

pub fn build(self) -> Pixel
where S: IsComplete,

Finish building and return the requested object

pub fn coordinates(self, value: (u32, u32)) -> PixelBuilder<SetCoordinates<S>>
where S::Coordinates: IsUnset,

Required.

The coordinates of the pixel. [0, 0] is in the top-left. The y-axis is twice as long as the number of rows in the terminal because 2 “pixels” can fit in a single TTY cell using the UTF8 half-block trick: ▀▄▀▄

pub fn color(self, value: Colour) -> PixelBuilder<SetColor<S>>
where S::Color: IsUnset,

Optional (Some / Option setters). An optional colour for the pixel. If None (or null in the case of JSON) is used then the default foreground colour is used.

pub fn maybe_color(self, value: Option<Colour>) -> PixelBuilder<SetColor<S>>
where S::Color: IsUnset,

Optional (Some / Option setters). An optional colour for the pixel. If None (or null in the case of JSON) is used then the default foreground colour is used.