pub struct PixelBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> PixelBuilder<S>
impl<S: State> PixelBuilder<S>
Sourcepub fn build(self) -> Pixelwhere
S: IsComplete,
pub fn build(self) -> Pixelwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn coordinates(self, value: (u32, u32)) -> PixelBuilder<SetCoordinates<S>>where
S::Coordinates: IsUnset,
pub fn coordinates(self, value: (u32, u32)) -> PixelBuilder<SetCoordinates<S>>where
S::Coordinates: IsUnset,
Required.
The coordinates of the pixel. [0, 0] is in the top-left. The y-axis is twice as long as the number of rows in the terminal because 2 “pixels” can fit in a single TTY cell using the UTF8 half-block trick: ▀▄▀▄
Sourcepub fn color(self, value: Colour) -> PixelBuilder<SetColor<S>>where
S::Color: IsUnset,
pub fn color(self, value: Colour) -> PixelBuilder<SetColor<S>>where
S::Color: IsUnset,
Sourcepub fn maybe_color(self, value: Option<Colour>) -> PixelBuilder<SetColor<S>>where
S::Color: IsUnset,
pub fn maybe_color(self, value: Option<Colour>) -> PixelBuilder<SetColor<S>>where
S::Color: IsUnset,